package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.client.AiptServiceClient;
import com.diagbot.dto.DisTypeDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.DisType;
import com.diagbot.entity.QuestionInfo;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.enums.QuestionTypeEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.DisTypeServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @Description: 诊断类型
 * @author: zhoutg
 * @time: 2018/11/19 13:19
 */
@Component
public class DisTypeFacade extends DisTypeServiceImpl {
    @Autowired
    private QuestionFacade questionFacade;
    @Autowired
    AiptServiceClient aiptServiceClient;

    /**
     * 返回诊断类型
     *
     * @return
     */
    public DisTypeDTO getDisTypeFac() {
        RespDTO<DisTypeDTO> res =  aiptServiceClient.getDisType();
        if (res == null || !CommonErrorCode.OK.getCode().equals(res.code)) {
            throw new CommonException(CommonErrorCode.RPC_ERROR, "远程调用诊断类型失败");
        }
        return res.data;
    }

    /**
     * 根据诊断id判断类型
     *
     * @param diseaseId
     * @param type
     * @return
     */
    public Boolean judgeByDisId(Long diseaseId, Integer type) {
        QueryWrapper<DisType> disTypeQueryWrapper = new QueryWrapper<>();
        disTypeQueryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("dis_id", diseaseId)
                .eq("type", type);
        DisType disType = this.getOne(disTypeQueryWrapper);
        if (disType == null) {
            return false;
        } else {
            return true;
        }
    }

    /**
     * 根据诊断名称判断类型
     *
     * @param disName
     * @param type
     * @return
     */
    public Boolean judgeByDisName(String disName, Integer type) {
        QueryWrapper<QuestionInfo> questionInfoQueryWrapper = new QueryWrapper<>();
        questionInfoQueryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("tag_name", disName)
                .eq("type", QuestionTypeEnum.Disease.getKey());
        QuestionInfo disease = questionFacade.getOne(questionInfoQueryWrapper);
        if (disease == null) {
            return false;
        } else {
            return judgeByDisId(disease.getId(), type);
        }
    }
}
